import { Observable } from 'data/observable';
import { ObservableArray } from 'tns-core-modules/data/observable-array/observable-array';

function ObservableProperty() {
    return (target: Observable, propertyKey: string) => {
        Object.defineProperty(target, propertyKey, {
            get() {
                return this["_" + propertyKey];
            },
            set(value) {
                if (this["_" + propertyKey] === value) {
                    return;
                }

                this["_" + propertyKey] = value;
                this.notifyPropertyChange(propertyKey, value);
            },
            enumerable: true,
            configurable: true
        });
    };
}

export class HelloWorldModel extends Observable {

    @ObservableProperty() public items: ObservableArray<{ title: string }>;

    constructor() {
        super();

        // Initialize default values.
        this.items = new ObservableArray([]);
    }   

    public onTap() {
        this.items.splice(0);
        this.items.push([
            { title: "Item 11" },
            { title: "Item 21" },
        ])
    }
}
